__version__ = '0.1'
__author__ = 'Giovanni Bajo <rasky@develer.com>'
__license__ = 'MIT'

from pool import ConnectionPool, retry

__all__ = ['ConnectionPool', 'retry']
